@@ -310,7 +310,7 @@ class PolarMapPanel(GeoPanel):
         if lat_label:
             pybasic.dict_set_default(lat_label_config, fontsize=plt.rcParams['font.size'] - 2, fontweight='roman',
                     ha='center', va='center',
-                    family='fantasy', color='k', alpha=0.9
+                    family='fantasy', alpha=0.9
                 )
             if self.pole == 'S':
                 clock = lat_label_clock / 12 * 360
@@ -342,7 +342,7 @@ class PolarMapPanel(GeoPanel):
             pybasic.dict_set_default(
                 lon_label_config,
                 va='center', ha='center',
-                family='fantasy', fontweight='ultralight', color='k')
+                family='fantasy', fontweight='ultralight')
             lb_lons = np.arange(0, 360., lon_res)
             if self.pole == 'S':
                 lon_shift_south = 180.
@@ -450,6 +450,7 @@ class PolarMapPanel(GeoPanel):
 
     def overlay_pcolormesh(
             self, data=None, coords=None, cs=None, *,
+            ut = None,
             regridding: bool = True,
             data_res: float = 0.7,
             grid_res: float = 0.1,
@@ -458,7 +459,6 @@ class PolarMapPanel(GeoPanel):
             **kwargs):
 
         kwargs.setdefault('shading', 'auto')
-
         if c_lim is None:
             c_lim = [0, 0]
             c_lim[0] = np.nanmin(data.flatten())
@@ -471,7 +471,7 @@ class PolarMapPanel(GeoPanel):
             kwargs.update(vmin=c_lim[0])
             kwargs.update(vmax=c_lim[1])
 
-        cs_new = self.cs_transform(cs_fr=cs, coords=coords)
+        cs_new = self.cs_transform(cs_fr=cs, coords=coords, ut=ut)
         lat_in = cs_new['lat']
         lon_in = cs_new['lon']
         data_in = data
@@ -541,7 +541,11 @@ class PolarMapPanel(GeoPanel):
         return ict
 
     def grid_data(self, lon_in, lat_in, data_in, grid_res=0.1, data_res=0.5, interp_method='linear'):
-        ind_data = np.where(np.isfinite(data_in))
+        if self.pole == "N":
+            sign_lat = 1.
+        else:
+            sign_lat = -1.
+        ind_data = np.where(np.isfinite(data_in) & (lat_in * sign_lat > (self.boundary_lat-5.)) & np.isfinite(lon_in))
         data_pts = data_in[ind_data]
         lat_pts = lat_in[ind_data]
         lon_pts = lon_in[ind_data]
